aboutsummaryrefslogtreecommitdiffhomepage
path: root/internal/rosa/busybox.go
diff options
context:
space:
mode:
Diffstat (limited to 'internal/rosa/busybox.go')
-rw-r--r--internal/rosa/busybox.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/internal/rosa/busybox.go b/internal/rosa/busybox.go
index 923f25ef..ae900a04 100644
--- a/internal/rosa/busybox.go
+++ b/internal/rosa/busybox.go
@@ -26,8 +26,8 @@ func (a busyboxBin) Params(*pkg.IContext) {}
// IsExclusive returns false: Cure performs a trivial filesystem write.
func (busyboxBin) IsExclusive() bool { return false }
-// Dependencies returns the underlying busybox [pkg.FileArtifact].
-func (a busyboxBin) Dependencies() []pkg.Artifact {
+// Inputs returns the underlying busybox [pkg.FileArtifact].
+func (a busyboxBin) Inputs() []pkg.Artifact {
return []pkg.Artifact{a.bin}
}